==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/operation/ConverterHtmlErrorReportType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ConverterHtmlErrorReportType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterHtmlErrorReportType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="mode" type="{http://schema.webpdf.de/1.0/operation}ConverterHtmlErrorReportModeType" default="none" />
 *       <attribute name="format" type="{http://schema.webpdf.de/1.0/operation}ConverterHtmlErrorReportFormatType" default="xml" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterHtmlErrorReportType")
public class ConverterHtmlErrorReportType {

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p117921_="https://jakarta.ee/xml/ns/jaxb" xmlns:p71612_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         This parameter specifies whether HTML content errors should be detected and, if so, how to provide a report with the errors. A detected error can be a failed download of a resource (for example, an image) or a script or CSS syntax error.&#13;
     *                         &lt;ul&gt;&lt;li&gt;none = No content errors are detected and no report is generated and returned.&lt;/li&gt;&lt;li&gt;message = Content errors are detected and the report is returned as part of the error message&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "mode")
    protected ConverterHtmlErrorReportModeType mode;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p117921_="https://jakarta.ee/xml/ns/jaxb" xmlns:p71612_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         Defines the output format of the error report.&#13;
     *                         &lt;ul&gt;&lt;li&gt;xml = XML document.&lt;/li&gt;&lt;li&gt;json = JSON document&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "format")
    protected ConverterHtmlErrorReportFormatType format;

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p117921_="https://jakarta.ee/xml/ns/jaxb" xmlns:p71612_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         This parameter specifies whether HTML content errors should be detected and, if so, how to provide a report with the errors. A detected error can be a failed download of a resource (for example, an image) or a script or CSS syntax error.&#13;
     *                         &lt;ul&gt;&lt;li&gt;none = No content errors are detected and no report is generated and returned.&lt;/li&gt;&lt;li&gt;message = Content errors are detected and the report is returned as part of the error message&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link ConverterHtmlErrorReportModeType }
     *     
     */
    public ConverterHtmlErrorReportModeType getMode() {
        if (mode == null) {
            return ConverterHtmlErrorReportModeType.NONE;
        } else {
            return mode;
        }
    }

    /**
     * Sets the value of the mode property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterHtmlErrorReportModeType }
     *     
     * @see #getMode()
     */
    public void setMode(ConverterHtmlErrorReportModeType value) {
        this.mode = value;
    }

    public boolean isSetMode() {
        return (this.mode!= null);
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p117921_="https://jakarta.ee/xml/ns/jaxb" xmlns:p71612_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         Defines the output format of the error report.&#13;
     *                         &lt;ul&gt;&lt;li&gt;xml = XML document.&lt;/li&gt;&lt;li&gt;json = JSON document&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link ConverterHtmlErrorReportFormatType }
     *     
     */
    public ConverterHtmlErrorReportFormatType getFormat() {
        if (format == null) {
            return ConverterHtmlErrorReportFormatType.XML;
        } else {
            return format;
        }
    }

    /**
     * Sets the value of the format property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterHtmlErrorReportFormatType }
     *     
     * @see #getFormat()
     */
    public void setFormat(ConverterHtmlErrorReportFormatType value) {
        this.format = value;
    }

    public boolean isSetFormat() {
        return (this.format!= null);
    }

}

==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ConverterHtmlErrorReportType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ConverterHtmlErrorReportType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterHtmlErrorReportType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="mode" type="{http://schema.webpdf.de/1.0/operation}ConverterHtmlErrorReportModeType" default="none" />
 *       <attribute name="format" type="{http://schema.webpdf.de/1.0/operation}ConverterHtmlErrorReportFormatType" default="xml" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterHtmlErrorReportType")
public class ConverterHtmlErrorReportType {

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p310440_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p351123_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         This parameter specifies whether HTML content errors should be detected and, if so, how to provide a report with the errors. A detected error can be a failed download of a resource (for example, an image) or a script or CSS syntax error.&#13;
     *                         &lt;ul&gt;&lt;li&gt;none = No content errors are detected and no report is generated and returned.&lt;/li&gt;&lt;li&gt;message = Content errors are detected and the report is returned as part of the error message&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "mode")
    protected ConverterHtmlErrorReportModeType mode;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p310440_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p351123_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         Defines the output format of the error report.&#13;
     *                         &lt;ul&gt;&lt;li&gt;xml = XML document.&lt;/li&gt;&lt;li&gt;json = JSON document&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "format")
    protected ConverterHtmlErrorReportFormatType format;

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p310440_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p351123_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         This parameter specifies whether HTML content errors should be detected and, if so, how to provide a report with the errors. A detected error can be a failed download of a resource (for example, an image) or a script or CSS syntax error.&#13;
     *                         &lt;ul&gt;&lt;li&gt;none = No content errors are detected and no report is generated and returned.&lt;/li&gt;&lt;li&gt;message = Content errors are detected and the report is returned as part of the error message&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link ConverterHtmlErrorReportModeType }
     *     
     */
    public ConverterHtmlErrorReportModeType getMode() {
        if (mode == null) {
            return ConverterHtmlErrorReportModeType.NONE;
        } else {
            return mode;
        }
    }

    /**
     * Sets the value of the mode property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterHtmlErrorReportModeType }
     *     
     * @see #getMode()
     */
    public void setMode(ConverterHtmlErrorReportModeType value) {
        this.mode = value;
    }

    public boolean isSetMode() {
        return (this.mode!= null);
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p310440_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p351123_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
     *                         Defines the output format of the error report.&#13;
     *                         &lt;ul&gt;&lt;li&gt;xml = XML document.&lt;/li&gt;&lt;li&gt;json = JSON document&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link ConverterHtmlErrorReportFormatType }
     *     
     */
    public ConverterHtmlErrorReportFormatType getFormat() {
        if (format == null) {
            return ConverterHtmlErrorReportFormatType.XML;
        } else {
            return format;
        }
    }

    /**
     * Sets the value of the format property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterHtmlErrorReportFormatType }
     *     
     * @see #getFormat()
     */
    public void setFormat(ConverterHtmlErrorReportFormatType value) {
        this.format = value;
    }

    public boolean isSetFormat() {
        return (this.format!= null);
    }

}
